@@ -6,26 +6,27 @@
 -- ============
 -- :import cvterm from cv
 -- :import pub from pub
--- :import dbxref from general
+-- :import dbxref from db
 -- :import organism from organism
 -- :import genotype from genetic
 -- :import contact from contact
-
+-- :import feature from sequence
+-- :import featuremap from map
 -- ================================================
 -- TABLE: stock
 -- ================================================
 
 create table stock (
-       stock_id serial not null,
+       stock_id bigserial not null,
        primary key (stock_id),
-       dbxref_id int,
+       dbxref_id bigint,
        foreign key (dbxref_id) references dbxref (dbxref_id) on delete set null INITIALLY DEFERRED,
-       organism_id int,
+       organism_id bigint,
        foreign key (organism_id) references organism (organism_id) on delete cascade INITIALLY DEFERRED,
        name varchar(255),
        uniquename text not null,
        description text,
-       type_id int not null,
+       type_id bigint not null,
        foreign key (type_id) references cvterm (cvterm_id) on delete cascade INITIALLY DEFERRED,
        is_obsolete boolean not null default 'false',
        constraint stock_c1 unique (organism_id,uniquename,type_id)
@@ -50,11 +51,11 @@ COMMENT ON COLUMN stock.name IS 'The name is a human-readable local name for a s
 -- ================================================
 
 create table stock_pub (
-       stock_pub_id serial not null,
+       stock_pub_id bigserial not null,
        primary key (stock_pub_id),
-       stock_id int not null,
+       stock_id bigint not null,
        foreign key (stock_id) references stock (stock_id)  on delete cascade INITIALLY DEFERRED,
-       pub_id int not null,
+       pub_id bigint not null,
        foreign key (pub_id) references pub (pub_id) on delete cascade INITIALLY DEFERRED,
        constraint stock_pub_c1 unique (stock_id,pub_id)
 );
@@ -69,11 +70,11 @@ COMMENT ON TABLE stock_pub IS 'Provenance. Linking table between stocks and, for
 -- ================================================
 
 create table stockprop (
-       stockprop_id serial not null,
+       stockprop_id bigserial not null,
        primary key (stockprop_id),
-       stock_id int not null,
+       stock_id bigint not null,
        foreign key (stock_id) references stock (stock_id) on delete cascade INITIALLY DEFERRED,
-       type_id int not null,
+       type_id bigint not null,
        foreign key (type_id) references cvterm (cvterm_id) on delete cascade INITIALLY DEFERRED,
        value text null,
        rank int not null default 0,
@@ -94,11 +95,11 @@ the combination of stock_id, rank, and type_id. Multivalued property-value pairs
 -- ================================================
 
 create table stockprop_pub (
-     stockprop_pub_id serial not null,
+     stockprop_pub_id bigserial not null,
      primary key (stockprop_pub_id),
-     stockprop_id int not null,
+     stockprop_id bigint not null,
      foreign key (stockprop_id) references stockprop (stockprop_id) on delete cascade INITIALLY DEFERRED,
-     pub_id int not null,
+     pub_id bigint not null,
      foreign key (pub_id) references pub (pub_id) on delete cascade INITIALLY DEFERRED,
      constraint stockprop_pub_c1 unique (stockprop_id,pub_id)
 );
@@ -113,13 +114,13 @@ COMMENT ON TABLE stockprop_pub IS 'Provenance. Any stockprop assignment can opti
 -- ================================================
 
 create table stock_relationship (
-       stock_relationship_id serial not null,
+       stock_relationship_id bigserial not null,
        primary key (stock_relationship_id),
-       subject_id int not null,
+       subject_id bigint not null,
        foreign key (subject_id) references stock (stock_id) on delete cascade INITIALLY DEFERRED,
-       object_id int not null,
+       object_id bigint not null,
        foreign key (object_id) references stock (stock_id) on delete cascade INITIALLY DEFERRED,
-       type_id int not null,
+       type_id bigint not null,
        foreign key (type_id) references cvterm (cvterm_id) on delete cascade INITIALLY DEFERRED,
        value text null,
        rank int not null default 0,
@@ -142,13 +143,13 @@ COMMENT ON COLUMN stock_relationship.value IS 'stock_relationship.value is for a
 -- ================================================
 
 CREATE TABLE stock_relationship_cvterm (
-	stock_relationship_cvterm_id SERIAL NOT NULL,
+	stock_relationship_cvterm_id bigserial NOT NULL,
 	PRIMARY KEY (stock_relationship_cvterm_id),
-	stock_relationship_id integer NOT NULL,
+	stock_relationship_id bigint NOT NULL,
 	FOREIGN KEY (stock_relationship_id) references stock_relationship (stock_relationship_id) ON DELETE CASCADE INITIALLY DEFERRED,
-	cvterm_id integer NOT NULL,
+	cvterm_id bigint NOT NULL,
 	FOREIGN KEY (cvterm_id) REFERENCES cvterm (cvterm_id) ON DELETE RESTRICT,
-	pub_id integer,
+	pub_id bigint,
 	FOREIGN KEY (pub_id) REFERENCES pub (pub_id) ON DELETE RESTRICT
 );
 COMMENT ON TABLE stock_relationship_cvterm is 'For germplasm maintenance and pedigree data, stock_relationship. type_id will record cvterms such as "is a female parent of", "a parent for mutation", "is a group_id of", "is a source_id of", etc The cvterms for higher categories such as "generative", "derivative" or "maintenance" can be stored in table stock_relationship_cvterm';
@@ -159,11 +160,11 @@ COMMENT ON TABLE stock_relationship_cvterm is 'For germplasm maintenance and ped
 -- ================================================
 
 create table stock_relationship_pub (
-      stock_relationship_pub_id serial not null,
+      stock_relationship_pub_id bigserial not null,
       primary key (stock_relationship_pub_id),
-      stock_relationship_id integer not null,
+      stock_relationship_id bigint not null,
       foreign key (stock_relationship_id) references stock_relationship (stock_relationship_id) on delete cascade INITIALLY DEFERRED,
-      pub_id int not null,
+      pub_id bigint not null,
       foreign key (pub_id) references pub (pub_id) on delete cascade INITIALLY DEFERRED,
       constraint stock_relationship_pub_c1 unique (stock_relationship_id,pub_id)
 );
@@ -178,11 +179,11 @@ COMMENT ON TABLE stock_relationship_pub IS 'Provenance. Attach optional evidence
 -- ================================================
 
 create table stock_dbxref (
-     stock_dbxref_id serial not null,
+     stock_dbxref_id bigserial not null,
      primary key (stock_dbxref_id),
-     stock_id int not null,
+     stock_id bigint not null,
      foreign key (stock_id) references stock (stock_id) on delete cascade INITIALLY DEFERRED,
-     dbxref_id int not null,
+     dbxref_id bigint not null,
      foreign key (dbxref_id) references dbxref (dbxref_id) on delete cascade INITIALLY DEFERRED,
      is_current boolean not null default 'true',
      constraint stock_dbxref_c1 unique (stock_id,dbxref_id)
@@ -199,16 +200,16 @@ COMMENT ON COLUMN stock_dbxref.is_current IS 'The is_current boolean indicates w
 -- ================================================
 
 create table stock_cvterm (
-     stock_cvterm_id serial not null,
+     stock_cvterm_id bigserial not null,
      primary key (stock_cvterm_id),
-     stock_id int not null,
+     stock_id bigint not null,
      foreign key (stock_id) references stock (stock_id) on delete cascade INITIALLY DEFERRED,
-     cvterm_id int not null,
+     cvterm_id bigint not null,
      foreign key (cvterm_id) references cvterm (cvterm_id) on delete cascade INITIALLY DEFERRED,
-     pub_id int not null,
+     pub_id bigint not null,
      foreign key (pub_id) references pub (pub_id) on delete cascade INITIALLY DEFERRED,
      is_not boolean not null default false,
-     rank integer not null default 0,
+     rank int not null default 0,
      constraint stock_cvterm_c1 unique (stock_id,cvterm_id,pub_id,rank)
  );
 create index stock_cvterm_idx1 on stock_cvterm (stock_id);
@@ -223,11 +224,11 @@ COMMENT ON TABLE stock_cvterm IS 'stock_cvterm links a stock to cvterms. This is
 -- ================================================
 
 create table stock_cvtermprop (
-    stock_cvtermprop_id serial not null,
+    stock_cvtermprop_id bigserial not null,
     primary key (stock_cvtermprop_id),
-    stock_cvterm_id int not null,
+    stock_cvterm_id bigint not null,
     foreign key (stock_cvterm_id) references stock_cvterm (stock_cvterm_id) on delete cascade,
-    type_id int not null,
+    type_id bigint not null,
     foreign key (type_id) references cvterm (cvterm_id) on delete cascade INITIALLY DEFERRED,
     value text null,
     rank int not null default 0,
@@ -263,11 +264,11 @@ the default 0 value should be used.';
 -- ================================================
 
 create table stock_genotype (
-       stock_genotype_id serial not null,
+       stock_genotype_id bigserial not null,
        primary key (stock_genotype_id),
-       stock_id int not null,
+       stock_id bigint not null,
        foreign key (stock_id) references stock (stock_id) on delete cascade,
-       genotype_id int not null,
+       genotype_id bigint not null,
        foreign key (genotype_id) references genotype (genotype_id) on delete cascade,
        constraint stock_genotype_c1 unique (stock_id, genotype_id)
 );
@@ -283,11 +284,11 @@ a genotype. Features with genotypes can be linked to stocks thru feature_genotyp
 -- ================================================
 
 create table stockcollection (
-	stockcollection_id serial not null, 
+	stockcollection_id bigserial not null, 
         primary key (stockcollection_id),
-	type_id int not null,
+	type_id bigint not null,
         foreign key (type_id) references cvterm (cvterm_id) on delete cascade,
-        contact_id int null,
+        contact_id bigint null,
         foreign key (contact_id) references contact (contact_id) on delete set null INITIALLY DEFERRED,
 	name varchar(255),
 	uniquename text not null,
@@ -310,11 +311,11 @@ COMMENT ON COLUMN stockcollection.contact_id IS 'contact_id links to the contact
 -- ================================================
 
 create table stockcollectionprop (
-    stockcollectionprop_id serial not null,
+    stockcollectionprop_id bigserial not null,
     primary key (stockcollectionprop_id),
-    stockcollection_id int not null,
+    stockcollection_id bigint not null,
     foreign key (stockcollection_id) references stockcollection (stockcollection_id) on delete cascade INITIALLY DEFERRED,
-    type_id int not null,
+    type_id bigint not null,
     foreign key (type_id) references cvterm (cvterm_id),
     value text null,
     rank int not null default 0,
@@ -334,11 +335,11 @@ COMMENT ON COLUMN stockcollectionprop.type_id IS 'The cv for the type_id is "sto
 -- ================================================
 
 create table stockcollection_stock (
-    stockcollection_stock_id serial not null,
+    stockcollection_stock_id bigserial not null,
     primary key (stockcollection_stock_id),
-    stockcollection_id int not null,
+    stockcollection_id bigint not null,
     foreign key (stockcollection_id) references stockcollection (stockcollection_id) on delete cascade INITIALLY DEFERRED,
-    stock_id int not null,
+    stock_id bigint not null,
     foreign key (stock_id) references stock (stock_id) on delete cascade INITIALLY DEFERRED,
     constraint stockcollection_stock_c1 unique (stockcollection_id,stock_id)
 );
@@ -355,11 +356,11 @@ a stock collection to the stocks which are contained in the collection.';
 -- ================================================
 
 create table stock_dbxrefprop (
-       stock_dbxrefprop_id serial not null,
+       stock_dbxrefprop_id bigserial not null,
        primary key (stock_dbxrefprop_id),
-       stock_dbxref_id int not null,
+       stock_dbxref_id bigint not null,
        foreign key (stock_dbxref_id) references stock_dbxref (stock_dbxref_id) on delete cascade INITIALLY DEFERRED,
-       type_id int not null,
+       type_id bigint not null,
        foreign key (type_id) references cvterm (cvterm_id) on delete cascade INITIALLY DEFERRED,
        value text null,
        rank int not null default 0,
@@ -374,3 +375,90 @@ hardcoding a list of columns in the relational schema, and is
 completely extensible. There is a unique constraint, stock_dbxrefprop_c1, for
 the combination of stock_dbxref_id, rank, and type_id. Multivalued property-value pairs must be differentiated by rank.';
 
+-- ================================================
+-- TABLE: stockcollection_db
+-- ================================================
+
+CREATE TABLE stockcollection_db (
+    stockcollection_db_id bigserial primary key NOT NULL,
+    stockcollection_id bigint NOT NULL,
+    db_id bigint NOT NULL,
+    CONSTRAINT stockcollection_db_c1 UNIQUE (stockcollection_id, db_id),
+    FOREIGN KEY (db_id) REFERENCES db(db_id) ON DELETE CASCADE,
+    FOREIGN KEY (stockcollection_id) REFERENCES stockcollection(stockcollection_id) ON DELETE CASCADE
+);
+
+CREATE INDEX stockcollection_db_idx1 ON stockcollection_db USING btree (stockcollection_id);
+CREATE INDEX stockcollection_db_idx2 ON stockcollection_db USING btree (db_id);
+
+COMMENT ON TABLE stockcollection_db IS 'Stock collections may be respresented 
+by an external online database. This table associates a stock collection with 
+a database where its member stocks can be found. Individual stock that are part 
+of this collction should have entries in the stock_dbxref table with the same 
+db_id record';
+
+
+-- ================================================
+-- TABLE: stock_feature
+-- ================================================
+
+CREATE TABLE stock_feature (
+  stock_feature_id bigserial NOT NULL,
+  feature_id bigint NOT NULL,
+  stock_id bigint NOT NULL,
+  type_id bigint NOT NULL,
+  rank INT NOT NULL DEFAULT 0,
+  PRIMARY KEY (stock_feature_id),
+  FOREIGN KEY (feature_id) REFERENCES feature (feature_id) ON DELETE CASCADE INITIALLY DEFERRED,
+  FOREIGN KEY (stock_id) REFERENCES stock (stock_id) ON DELETE CASCADE INITIALLY DEFERRED,
+  FOREIGN KEY (type_id) REFERENCES cvterm (cvterm_id) ON DELETE CASCADE INITIALLY DEFERRED,
+  CONSTRAINT stock_feature_c1 UNIQUE (feature_id, stock_id, type_id, rank)  
+);
+create index stock_feature_idx1 on stock_feature (stock_feature_id);
+create index stock_feature_idx2 on stock_feature (feature_id);
+create index stock_feature_idx3 on stock_feature (stock_id);
+create index stock_feature_idx4 on stock_feature (type_id);
+
+COMMENT ON TABLE stock_feature  IS 'Links a stock to a feature.';
+
+
+-- ================================================
+-- TABLE: stock_featuremap
+-- ================================================
+
+CREATE TABLE stock_featuremap (
+  stock_featuremap_id bigserial NOT NULL,
+  featuremap_id bigint NOT NULL,
+  stock_id bigint NOT NULL,
+  type_id bigint,
+  PRIMARY KEY (stock_featuremap_id),
+  FOREIGN KEY (featuremap_id) REFERENCES featuremap (featuremap_id) ON DELETE CASCADE INITIALLY DEFERRED,
+  FOREIGN KEY (stock_id) REFERENCES stock (stock_id)  ON DELETE CASCADE INITIALLY DEFERRED,
+  FOREIGN KEY (type_id) REFERENCES cvterm (cvterm_id) ON DELETE CASCADE INITIALLY DEFERRED,
+  CONSTRAINT stock_featuremap_c1 UNIQUE (featuremap_id, stock_id, type_id)  
+);
+
+create index stock_featuremap_idx1 on stock_featuremap (featuremap_id);
+create index stock_featuremap_idx2 on stock_featuremap (stock_id);
+create index stock_featuremap_idx3 on stock_featuremap (type_id);
+
+COMMENT ON TABLE stock_featuremap  IS 'Links a featuremap to a stock.';
+
+
+-- ================================================
+-- TABLE: stock_library
+-- ================================================
+CREATE TABLE stock_library (
+    stock_library_id bigserial primary key NOT NULL,
+    library_id bigint NOT NULL,
+    stock_id bigint NOT NULL,
+    CONSTRAINT stock_library_c1 UNIQUE (library_id, stock_id),
+    FOREIGN KEY (library_id) REFERENCES library(library_id) ON DELETE CASCADE,
+    FOREIGN KEY (stock_id) REFERENCES stock(stock_id) ON DELETE CASCADE
+);
+
+CREATE INDEX stock_library_idx1 ON stock_library USING btree (library_id);
+CREATE INDEX stock_library_idx2 ON stock_library USING btree (stock_id);
+
+COMMENT ON TABLE stock_library IS 'Links a stock with a library.';
+
